pub type Weigher = WeightInfoBounds<FrequencyXcmWeight<RuntimeCall>, RuntimeCall, MaxInstructions>;Expand description
The XCM weigher used to estimate total weight for execution
Aliased Type
pub struct Weigher(/* private fields */);pub type Weigher = WeightInfoBounds<FrequencyXcmWeight<RuntimeCall>, RuntimeCall, MaxInstructions>;The XCM weigher used to estimate total weight for execution
pub struct Weigher(/* private fields */);